// B4R Library for 1 to 4 digit x 7 segment LED displays
// Changelog
// 20190622: NEW
#pragma once
#include "B4RDefines.h"
#include "SevSeg.h"

namespace B4R {
	//~Version: 1.0
	//~shortname: SevSeg
	class B4RSevSeg {
		private:
			SevSeg* bn;
			uint8_t be[sizeof(SevSeg)];
		public:

					/**
			*
			*For Common Cathode displays
			*
			*/		
			bool CommonCathode = 0;
			/**
			*
			*For Common Anode displays
			*
			*/					
			bool CommonAnode = 1;
			
			/**
			*
			*Initializes the SevSeg object
			*
			*/			
			void initialize();
			
			/**
			*
			*Call Begin...
			*Eg:
			*svg.initialize
			*svg.Begin(svg.CommonCathode, 4, 13, 12, 11, 10, 2, 3, 4, 5, 6, 7, 8, 9)
			*
			*svg.CommonCathode -> set to common cathode when using a common cathode display
			*4 -> number of digits on the display
			*13 -> pin number on MCU for control of digit 1 (left most or Most Significant digit on the display)
			*12 -> pin number on MCU for control of digit 2 
			*11 -> pin number on MCU for control of digit 3 
			*10 -> pin number on MCU for control of digit 4 (Right most or Least Significant digit on the display)
			*2 -> pin 2 of the MCU will control segment A of each digit
			*3 -> pin 3 of the MCU will control segment B of each digit
			*4 -> pin 4 of the MCU will control segment C of each digit
			*5 -> pin 5 of the MCU will control segment D of each digit
			*6 -> pin 6 of the MCU will control segment E of each digit
			*7 -> pin 7 of the MCU will control segment F of each digit
			*8 -> pin 8 of the MCU will control segment G of each digit
			*9 -> pin 9 of the MCU will control segment DP of each digit
			*/					
			void Begin(bool mode_in, byte numOfDigits, byte dig1, byte dig2, byte dig3, byte dig4, byte segA, byte segB, byte segC, byte segD, byte segE, byte segF, byte segG, byte segDP);
				
			/**
			*
            *Set Brightness from 0 to 100%
			*/
			void SetBrightness(Byte percentBright);
			
			/**
			*
            *Display a B4R String 
			*Eg:
			*Dim data As String = "1234"
			*svg.DisplayB4RString(data, 0)
            *DecAposColon -> position of the Decimal Point			
			*/						
			void DisplayB4RString(B4RString* toDisplay, Byte DecAposColon);
			
			/**
			*
            *Display a B4R Byte Array 
			*Eg:
			*Dim data() As Byte = "1234"
			*svg.DisplayB4RByteArray(data, 0)
            *DecAposColon -> position of the Decimal Point				
			*/				
			void DisplayB4RByteArray(ArrayByte* toDisplay, Byte DecAposColon);
			


			
	};

}